/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package jreqtools;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import jreqtools.gadgets.*;

/**
* This is a requester for look and feels. The chosen look and feel can also be set immediately.
* 
* @author	Markus Hillenbrand
*/

public class LookAndFeelRequester extends AbstractRequester {
	private static String []	classnames		= null;
	
	private int 				lookandfeel 	= 0;
	private String			message		= null;
	private	int 				answer			= CANCEL;
	private	Component		set				= null;
	
	private class Dialog extends JDialog {
		private ComboBox combobox = new ComboBox(getInstalledLookAndFeels());
		
		public Dialog(JFrame parent)  {
			super(parent, "JReqTools: LookAndFeelRequester", true);
			
			// Gadgets initialisieren
			combobox.setSelectedIndex(lookandfeel);
			
			// Buttons erzeugen
			OkCancelButtons buttons = new OkCancelButtons(LookAndFeelRequester.this,
				new ActionListener() { public void actionPerformed(ActionEvent e) { ok(); } },
				new ActionListener() { public void actionPerformed(ActionEvent e) { cancel(); } },
				listener);
			
			// Panel erzeugen
			JPanel p = new YFramePanel();
			p.add(Box.createVerticalGlue());
			p.add(new MessagePanel(message, combobox));
			p.add(Box.createVerticalGlue());
			p.add(new Strut());
			p.add(buttons);
			
			// Alles hinzufgen
			setContentPane(p);
			getLayeredPane().add(new BackgroundImage(), new Integer(Integer.MIN_VALUE));
			pack();
		}

		private void cancel()  {
			answer = CANCEL;
			setVisible(false);
		}

		private void ok()  {
			answer = OK;
			lookandfeel = combobox.getSelectedIndex();
			setVisible(false);
			
			if (set != null)
				{
				try
					{
					UIManager.setLookAndFeel(classnames[lookandfeel]);
					SwingUtilities.updateComponentTreeUI(SwingUtilities.getRoot(set));
					}
				catch (UnsupportedLookAndFeelException un)
					 {
					 JReqTools.showError(JReqTools.getResourceString(
					 	"Error.01", 
					 	getInstalledLookAndFeels()[combobox.getSelectedIndex()])); 
					 }
				catch (Exception x) 
					{ 
					System.out.println(x); 
					}
				}
		}

		public void setVisible(boolean b)  {
			if (b) combobox.requestFocus();
			super.setVisible(b);
		}

	}

	public LookAndFeelRequester()  {
		this("JReqTools: LookAndFeelRequester", null);
	}

	public LookAndFeelRequester(String message)  {
		this("JReqTools: LookAndFeelRequester", message);
	}

	public LookAndFeelRequester(String title, String message)  {
		setTitle(title);
		setMessage(message);
	}

	static {
		try
			{
			boolean found = false;
			
			Class c = Class.forName("swing.addon.plaf.threeD.ThreeDLookAndFeel");
			
			UIManager.LookAndFeelInfo [] lfs = UIManager.getInstalledLookAndFeels();
			for (int i=0; i<lfs.length; ++i) if (lfs[i].getClassName().equals("swing.addon.plaf.threeD.ThreeDLookAndFeel")) found = true;
			
			if (! found) UIManager.installLookAndFeel("3D Look & Feel", "swing.addon.plaf.threeD.ThreeDLookAndFeel");
			}
		catch (ClassNotFoundException x) { }
		
		try
			{
			boolean found = false;
			
			Class c = Class.forName("swing.addon.plaf.ultimate.UltimateLookAndFeel");
			
			UIManager.LookAndFeelInfo [] lfs = UIManager.getInstalledLookAndFeels();
			for (int i=0; i<lfs.length; ++i) if (lfs[i].getClassName().equals("swing.addon.plaf.ultimate.UltimateLookAndFeel")) found = true;
			
			if (! found) UIManager.installLookAndFeel("Ultimate Look & Feel", "swing.addon.plaf.ultimate.UltimateLookAndFeel");
			}
		catch (ClassNotFoundException x) { }
	}

	protected javax.swing.JDialog createJDialog(JFrame parent)  {
		return new Dialog(parent);
	}

	public static String [] getInstalledLookAndFeels()  {
		UIManager.LookAndFeelInfo [] info = UIManager.getInstalledLookAndFeels();
		
		String [] result = new String [info.length];
		classnames = new String[info.length];
		
		for (int i=0; i<info.length; i++)
			{
			result[i] = info[i].getName();
			classnames[i] = info[i].getClassName();
			}
		
		return result;
	}

	public String getLookAndFeel()  {
		return classnames[lookandfeel];
	}

	protected int getReturnValue()  {
		return answer;
	}

	public void setAfterSelection(Component tree)  {
		set = tree;
	}

	/**
	* Sets the message to be shown in the requester.
	*/

	public void setMessage(String newmessage)  {
		message = newmessage;
	}

}
